@@ -237,6 +237,18 @@ namespace IOFireWireLib {
 		protected:
 			typedef ::IOFireWireLibLocalIsochPortRef	PortRef ;
 		
+		protected:
+
+			DCLCommand*									mDCLProgram ;
+			UInt32										mStartEvent ;
+			UInt32										mStartState ;
+			UInt32										mStartMask ;
+			UInt32										mExpectedStopTokens ;
+			unsigned									mDeferredReleaseCount ;
+			io_async_ref_t								mAsyncRef ;
+			pthread_mutex_t								mMutex ;		
+			IOFireWireLibIsochPortFinalizeCallback		mFinalizeCallback ;
+
 		public:
 									LocalIsochPort( IUnknownVTbl* interface, Device& inUserClient, bool inTalking,
 														DCLCommand* inDCLProgram, UInt32 inStartEvent, UInt32 inStartState,
@@ -251,24 +263,13 @@ namespace IOFireWireLib {
 			// local port methods:
 			IOReturn				ModifyJumpDCL( DCLJump* inJump, DCLLabelStruct* inLabel ) ;
 			IOReturn				ModifyTransferPacketDCLSize( DCLTransferPacket* dcl, IOByteCount newSize ) ;			
-			static void				DCLCallProcHandler( void* inRefCon, IOReturn result, LocalIsochPort* me) ;
+			void					DCLCallProcHandler( void* refcon, IOReturn result ) ;
+			static void				S_DCLCallProcHandler( void* refcon, IOReturn result, LocalIsochPort* me) ;
 			void					Lock() ;
 			void					Unlock() ;
 		
 			// utility functions:
-			void					PrintDCLProgram( const DCLCommand* inProgram, UInt32 inLength ) ;
-		
-		protected:
-			DCLCommand*				mDCLProgram ;
-			UInt32							mStartEvent ;
-			UInt32							mStartState ;
-			UInt32							mStartMask ;
-			UInt32							mExpectedStopTokens ;
-			Boolean							mDeferredRelease ;
-			
-			io_async_ref_t					mAsyncRef ;
-		
-			pthread_mutex_t					mMutex ;		
+			void					PrintDCLProgram( const DCLCommand* inProgram, UInt32 inLength ) ;		
 	} ;
 	
 	// ============================================================
@@ -284,6 +285,7 @@ namespace IOFireWireLib {
 		typedef ::IOFireWireLibLocalIsochPortRef PortRef ;
 		
 		public:
+		
 			LocalIsochPortCOM( Device& userclient, bool inTalking, DCLCommand* inDCLProgram, UInt32 inStartEvent,
 					UInt32 inStartState, UInt32 inStartMask, IOVirtualRange inDCLProgramRanges[], 
 					UInt32 inDCLProgramRangeCount, IOVirtualRange inBufferRanges[], UInt32 inBufferRangeCount) ;
@@ -317,8 +319,10 @@ namespace IOFireWireLib {
 			static IOReturn			SModifyTransferPacketDCLSize( PortRef self, DCLTransferPacket* dcl, IOByteCount newSize ) ;
 			static IOReturn			SModifyTransferPacketDCLBuffer( PortRef self, DCLTransferPacket* dcl, void* newBuffer ) ;
 			static IOReturn			SModifyTransferPacketDCL( PortRef self, DCLTransferPacket* dcl, void* newBuffer, IOByteCount newSize ) ;
-
+			static IOReturn			S_SetFinalizeCallback( IOFireWireLibLocalIsochPortRef self, IOFireWireLibIsochPortFinalizeCallback finalizeCallback ) ;
+			
 		protected:
+		
 			static Interface	sInterface ;
 	} ;
 	
